@@ -3,6 +3,7 @@ import pandas as pd
 from spongebox.rebox import filter_list
 import spongebox.timebox as timebox
 import logging
+import zipfile
 
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
@@ -48,8 +49,9 @@ def list_dir(dir_path, exp=None):
     else:
         return filter_list(os.listdir(dir_path), exp=exp)
 
-def read_overwrite(path,text_process_func,encoding="utf-8"):
-    with open(path,"r+",encoding=encoding) as f:
+
+def read_overwrite(path, text_process_func, encoding="utf-8"):
+    with open(path, "r+", encoding=encoding) as f:
         content = text_process_func(f.read())
         f.seek(0)
         f.truncate()
@@ -67,15 +69,22 @@ def list_all_files(dir_path):
     return lst
 
 
-if __name__ == "__main__":
-	mylog = log()
-	mylog.logger.debug("haha")
-    # print(list_dir("../", exp=".*md$"))
-    # lst = []
-    # lst1=[]
-    # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst))
-    # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst1))
-    # print(walk_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
-    # list_all_files("C:\\Users\\LuoJi\\Documents\\05照片")
-    # print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
+def zip_dir(zip_name, dir_path):
+    arch = dir_path.replace("\\", "/").split("/")[-1]
+    with zipfile.ZipFile(zip_name, "w") as myzip:
+        for fname in list_all_files(dir_path):
+            print(fname)
+            myzip.write(fname, fname.replace(dir_path, arch).replace("\\", "/"))
 
+
+if __name__ == "__main__":
+    mylog = log()
+    mylog.logger.debug("haha")
+# print(list_dir("../", exp=".*md$"))
+# lst = []
+# lst1=[]
+# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst))
+# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test",lst1))
+# print(walk_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
+# list_all_files("C:\\Users\\LuoJi\\Documents\\05照片")
+# print(list_all_files("C:\\Users\\LuoJi\\Downloads\\test"))
